package org.jeecg.modules.itdmWenxiangHistory.mapper;

import org.apache.ibatis.annotations.Param;
import org.apache.ibatis.annotations.Select;

import java.util.Date;

public interface YCDataMapper {


    /**删除0.5立方硬采表所给日期之前的所有数据*/
    @Select("delete from cssy_yj_w05 where gather_time <= #{lastYearOfToday}")
    void deleteYCDataByTime05(@Param("lastYearOfToday") Date lastYearOfToday);

    /**删除1立方硬采表所给日期之前的所有数据*/
    @Select("delete from cssy_yj_w1 where gather_time <= #{lastYearOfToday}")
    void deleteYCDataByTime1(@Param("lastYearOfToday") Date lastYearOfToday);

    /**删除8立方硬采表所给日期之前的所有数据*/
    @Select("delete from cssy_yj_w8 where gather_time <= #{lastYearOfToday}")
    void deleteYCDataByTime8(@Param("lastYearOfToday") Date lastYearOfToday);

    /**删除16立方硬采表所给日期之前的所有数据*/
    @Select("delete from cssy_yj_w16 where gather_time <= #{lastYearOfToday}")
    void deleteYCDataByTime16(@Param("lastYearOfToday") Date lastYearOfToday);

    /**删除48立方硬采表所给日期之前的所有数据*/
    @Select("delete from cssy_yj_w48 where gather_time <= #{lastYearOfToday}")
    void deleteYCDataByTime48(@Param("lastYearOfToday") Date lastYearOfToday);

    /**删除霉菌硬采表所给日期之前的所有数据*/
    @Select("delete from cssy_yj_wmj where gather_time <= #{lastYearOfToday}")
    void deleteYCDataByTimeMJ(@Param("lastYearOfToday") Date lastYearOfToday);

    /**删除三综合硬采表所给日期之前的所有数据*/
    @Select("delete from cssy_yj_wszh where gather_time <= #{lastYearOfToday}")
    void deleteYCDataByTimeSZH(@Param("lastYearOfToday") Date lastYearOfToday);




}
